.. image:: https://img.shields.io/github/license/saltstack/salt
   :alt: Salt Project License: Apache v2.0
   :target: https://github.com/saltstack/salt/blob/master/LICENSE

.. image:: https://img.shields.io/pypi/dm/salt?label=pypi%20downloads
   :alt: PyPi Package Downloads
   :target: https://pypi.org/project/salt

.. image:: https://img.shields.io/badge/discord-SaltProject-blue.svg?logo=discord
   :alt: Salt Project Discord Community
   :target: https://discord.com/invite/J7b7EscrAs

.. image:: https://img.shields.io/reddit/subreddit-subscribers/saltstack?style=social
   :alt: Salt Project subreddit
   :target: https://www.reddit.com/r/saltstack/

.. image:: https://img.shields.io/twitter/follow/Salt_Project_OS?style=social&logo=twitter
   :alt: Follow SaltStack on Twitter
   :target: https://twitter.com/intent/follow?screen_name=Salt_Project_OS

.. figure:: https://gitlab.com/saltstack/open/salt-branding-guide/-/raw/master/logos/SaltProject_altlogo_teal.png?inline=true
   :scale: 80 %
   :width: 1000px
   :height: 356px
   :align: center
   :alt: Salt Project Logo

* `Latest Salt Documentation`_
* `Open an issue`_ (bug report, feature request, etc.)

*Salt is the world's fastest, most intelligent and scalable automation*
*engine.*

About Salt
==========
Built on Python, Salt is an event-driven automation tool and framework to
deploy, configure, and manage complex IT systems. Use Salt to automate common
infrastructure administration tasks and ensure that all the components of your
infrastructure are operating in a consistent desired state.

Salt has many possible uses, including configuration management, which involves:

* Managing operating system deployment and configuration.
* Installing and configuring software applications and services.
* Managing servers, virtual machines, containers, databases, web servers,
  network devices, and more.
* Ensuring consistent configuration and preventing configuration drift.

Salt is ideal for configuration management because it is pluggable,
customizable, and plays well with many existing technologies. Salt enables you
to deploy and manage applications that use any tech stack running on nearly any
`operating system <https://docs.saltproject.io/salt/install-guide/en/latest/topics/salt-supported-operating-systems.html>`_,
including different types of network devices such as switches and routers from a
variety of vendors.

In addition to configuration management Salt can also:

* Automate and orchestrate routine IT processes, such as common required tasks
  for scheduled server downtimes or upgrading operating systems or applications.
* Create self-aware, self-healing systems that can automatically respond to
  outages, common administration problems, or other important events.


About our sponsors
==================

Salt powers VMware by Broadcom's `Tanzu Salt`_
(previously Aria Automation Config / vRealize Automation SaltStack Config / SaltStack Enterprise), and can be found
under the hood of products from Juniper, Cisco, Cloudflare, Nutanix, SUSE, and
Tieto, to name a few.

The original sponsor of our community, SaltStack, was acquired by VMware in 2020.
`VMware was later acquired by Broadcom in 2023 <https://investors.broadcom.com/news-releases/news-release-details/broadcom-completes-acquisition-vmware>`__.
The Salt Project remains an open source ecosystem that Broadcom supports and
contributes to. Broadcom ensures the code integrity and quality of the Salt
modules by acting as the official sponsor and manager of the Salt project. Many
of the core Salt Project contributors are also Broadcom employees. This team
carefully reviews and enhances the Salt modules to ensure speed, quality, and
security.

Download and install Salt
=========================
Salt is tested and packaged to run on CentOS, Debian, RHEL, Ubuntu, MacOS,
Windows, and more. Download Salt and get started now. See
`supported operating systems <https://docs.saltproject.io/salt/install-guide/en/latest/topics/salt-supported-operating-systems.html>`_
for more information.

To download and install Salt, see:

* `The Salt install guide <https://docs.saltproject.io/salt/install-guide/en/latest/index.html>`_
    * `Salt Project Repository: Linux (RPM) <https://packages.broadcom.com/artifactory/saltproject-rpm>`__ - Where Salt ``rpm`` packages are officially stored and distributed.
    * `Salt Project Repository: Linux (DEB) <https://packages.broadcom.com/artifactory/saltproject-deb>`__ - Where Salt ``deb`` packages are officially stored and distributed.
    * `Salt Project Repository: GENERIC <https://packages.broadcom.com/artifactory/saltproject-generic>`__ - Where Salt Windows, macOS, etc. (non-rpm, non-deb) packages are officially stored and distributed.

Technical support
=================
Report bugs or problems using Salt by opening an issue: `<https://github.com/saltstack/salt/issues>`_

To join our community forum where you can exchange ideas, best practices,
discuss technical support questions, and talk to project maintainers, join our
Discord server: `Salt Project Community Discord`_



Salt Project documentation
==========================
Installation instructions, tutorials, in-depth API and module documentation:

* `The Salt install guide <https://docs.saltproject.io/salt/install-guide/en/latest/index.html>`_
* `The Salt user guide <https://docs.saltproject.io/salt/user-guide/en/latest/>`_
* `Latest Salt documentation`_
* `Salt's contributing guide <https://docs.saltproject.io/en/master/topics/development/contributing.html>`_


Security advisories
===================
Keep an eye on the Salt Project
`Security Announcements <https://saltproject.io/security-announcements/>`_
landing page. Salt Project recommends subscribing to the
`Salt Project Security RSS feed <https://saltproject.io/security-announcements/index.xml>`_
to receive notification when new information is available regarding security
announcements.

Other channels to receive security announcements include the
`Salt Community mailing list <https://groups.google.com/forum/#!forum/salt-users>`_
and the `Salt Project Community Discord`_.


Responsibly reporting security vulnerabilities
++++++++++++++++++++++++++++++++++++++++++++++
When reporting security vulnerabilities for Salt or other SaltStack projects,
refer to the `SECURITY.md`_ file found in this repository.


Join our community
==================
Salt is built by the Salt Project community, which includes more than 3,000
contributors working in roles just like yours. This well-known and trusted
community works together to improve the underlying technology and extend Salt by
creating a variety of execution and state modules to accomplish the most common
tasks or solve the most important problems that people in your role are likely
to face.

If you want to help extend Salt or solve a problem with Salt, you can join our
community and contribute today.

Please be sure to review our
`Code of Conduct <https://github.com/saltstack/salt/blob/master/CODE_OF_CONDUCT.md>`_.
Also, check out some of our community resources including:

* `Salt Project Community Discord`_
* `Salt Project YouTube channel <https://www.youtube.com/channel/UCpveTIucFx9ljGelW63-BWg>`_
* `Salt Project Community Notes and Wiki <https://github.com/saltstack/community/>`_

There are lots of ways to get involved in our community. Every month, there are
around a dozen opportunities to meet with other contributors and the Salt Core
team and collaborate in real time. The best way to keep track is by subscribing
to the **Salt Project Community Events Calendar** on the main
`<https://saltproject.io>`_ website.

If you have additional questions, email us at saltproject.pdl@broadcom.com or reach out
directly to the Community Discord. We'd be glad to have you join our community!

License
=======
Salt is licensed under the Apache 2.0 license. Please
see the
`LICENSE file <https://github.com/saltstack/salt/blob/master/LICENSE>`_ for the
full text of the Apache license, followed by a full summary of the licensing
used by external modules.

A complete list of attributions and dependencies can be found here:
`salt/DEPENDENCIES.md <https://github.com/saltstack/salt/blob/master/DEPENDENCIES.md>`_

.. _Salt Project Community Discord: https://discord.com/invite/J7b7EscrAs
.. _Tanzu Salt: https://www.vmware.com/products/app-platform/tanzu-salt
.. _Latest Salt Documentation: https://docs.saltproject.io/en/latest/
.. _Open an issue: https://github.com/saltstack/salt/issues/new/choose
.. _SECURITY.md: https://github.com/saltstack/salt/blob/master/SECURITY.md
